==> HostCMS.Free_6.7.tar.gz: modules/template/i18n/en.php <==
<?php
/**
 * Templates.
 *
 * @package HostCMS
 * @subpackage Template
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Тemplates',
	'menu' => 'Тemplates',
	'title' => 'Тemplates',
	'menu1' => 'Template',
	'menu_add' => 'Add',
	'title_add' => 'Add template',
	'title_edit' => 'Edit template "%s"',
	'tab_1' => 'Template',
	'tab_2' => 'CSS/LESS',
	'tab_3' => 'Javascript',
	'tab_4' => 'Manifest',
	'breadCrumb' => 'Template "%s"',
	'id' => 'Id',
	'name' => '<acronym title="Template name">Template name</acronym>',
	'template_dir_id' => '<acronym title="Template section that template belongs to">Template section</acronym>',
	'sorting' => '<acronym title="Field according to which it should be sorted">Sorting</acronym>',
	'site_id' => 'Site Id',
	'template_id' => 'Parent template Id',
	'template_id' => 'Parent template',
	'template' => '<acronym title="Template code">Template</acronym>',
	'css' => '<acronym title="CSS or LESS">CSS/LESS</acronym>',
	'less' => '<acronym title="Стиль использует LESS">LESS</acronym>',
	'js' => '<acronym title="JS scripts">Javascript</acronym>',
	'manifest' => '<acronym title="Manifest for LESS">Manifest</acronym>',
	'copy_success' => 'Template copied successfully!',
	'copy_error' => 'Error! Template has not been copied!',
	'markDeleted_success' => 'Template deleted successfully!',
	'markDeleted_error' => 'Error! Template has not been deleted!',
	'edit_success' => 'Template added successfully!',
	'edit_error' => 'Error! Template has not been added!',
	'apply_success' => 'Template updated successfully!',
	'apply_error' => 'Error! Template has not been modified!',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'error_less_off' => 'Temlate\'s LESS has been disabled. Edit template and turn on it.',
	'error_access_forbidden' => 'You do not have permission to edit.',
);

==> HostCMS.Free_7.0.tar.gz: modules/template/i18n/en.php <==
<?php
/**
 * Templates.
 *
 * @package HostCMS
 * @subpackage Template
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2020 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Тemplates',
	'menu' => 'Тemplates',
	'title' => 'Тemplates',
	'menu1' => 'Template',
	'menu_add' => 'Add',
	'title_add' => 'Add template',
	'title_edit' => 'Edit template "%s"',
	'tab_1' => 'Template',
	'tab_2' => 'CSS/LESS/SCSS',
	'tab_3' => 'Javascript',
	'tab_4' => 'Manifest',
	'tab_5' => 'Language',
	'breadCrumb' => 'Template "%s"',
	'id' => 'ID',
	'name' => 'Template name',
	'template_dir_id' => 'Template section',
	'sorting' => 'Sort',
	'site_id' => 'Site Id',
	'template_id' => 'Parent template Id',
	'template' => '<acronym title="Template code">Template</acronym>',
	'css' => '<acronym title="CSS or LESS">CSS/LESS/SCSS</acronym>',
	'less' => '<acronym title="Apply LESS">LESS</acronym>',
	'js' => '<acronym title="JS scripts">Javascript</acronym>',
	'manifest' => '<acronym title="Manifest for LESS">Manifest</acronym>',
	'copy_success' => 'Template copied successfully!',
	'copy_error' => 'Error! Template has not been copied!',
	'markDeleted_success' => 'Template deleted successfully!',
	'markDeleted_error' => 'Error! Template has not been deleted!',
	'edit_success' => 'Template added successfully!',
	'edit_error' => 'Error! Template has not been added!',
	'apply_success' => 'Template updated successfully!',
	'apply_error' => 'Error! Template has not been modified!',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'error_less_off' => 'Temlate\'s LESS has been disabled. Edit template and turn on it.',
	'error_access_forbidden' => 'You do not have permission to edit.',
	'language' => '%s.php',
	'type' => 'Type',
);
